@@ -1,6 +1,7 @@
-from typing import Any
-
+import hashlib
+from typing import Any, Union
 from aws_cdk.aws_apigatewayv2 import CfnIntegration
+from aws_cdk.aws_lambda import IFunction, CfnFunction
 from aws_cdk.core import Stack
 
 
@@ -10,12 +11,18 @@ class LambdaIntegration(CfnIntegration):
             scope: Stack,
             integration_name: str,
             api: Any,
-            lambda_function: Any,
+            lambda_function: Union[IFunction, CfnFunction],
             integration_method: str = 'POST',
             integration_type: str = 'AWS_PROXY',
             connection_type='INTERNET',
             **kwargs
     ) -> None:
+        self.__integration_name = integration_name
+        self.__lambda_function = lambda_function
+        self.__integration_method = integration_method
+        self.__integration_type = integration_type
+        self.__connection_type = connection_type
+
         try:
             # Works for higher level constructs.
             api_id = api.rest_api_id
@@ -47,3 +54,18 @@ class LambdaIntegration(CfnIntegration):
             payload_format_version='1.0',
             **kwargs
         )
+
+    @property
+    def function(self) -> Union[IFunction, CfnFunction]:
+        return self.__lambda_function
+
+    @property
+    def hash(self):
+        hashable = (
+            self.__integration_name +
+            self.__integration_method +
+            self.__integration_type +
+            self.__connection_type
+        ).encode('utf-8')
+
+        return hashlib.sha256(hashable).hexdigest()
